package com.mortals.xhx.module.customer.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.common.IBaseEnum;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.common.code.MemberLevelEnum;
import com.mortals.xhx.common.code.TrialAcceptEnum;
import com.mortals.xhx.module.customer.model.CustomerTrialEntity;
import com.mortals.xhx.module.customer.service.CustomerTrialService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.Map;
/**
*
* 客户试用申请
*
* @author zxfei
* @date 2022-06-08
*/
@RestController
@RequestMapping("customer/trial")
public class CustomerTrialController extends BaseCRUDJsonBodyMappingController<CustomerTrialService,CustomerTrialEntity,Long> {

    @Autowired
    private ParamService paramService;

    public CustomerTrialController(){
        super.setModuleDesc( "客户试用申请");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model,"memberLevel", IBaseEnum.getEnumMap(MemberLevelEnum.class,0));
        this.addDict(model,"isAccept", IBaseEnum.getEnumMap(TrialAcceptEnum.class));
        super.init(model, context);
    }

    @Override
    protected void doListBefore(CustomerTrialEntity query, Map<String, Object> model, Context context) throws AppException {
        Map<String,String> orderCols = new HashMap<>();
        orderCols.put("createTime","DESC");
        query.setOrderCols(orderCols);
    }

    @PostMapping({"accept"})
    public String accept(@RequestBody CustomerTrialEntity entity) {
        Map<String, Object> model = new HashMap();
        int code = 1;
        Context context = this.getContext();
        String busiDesc = "受理客户申请";
        try {
            this.service.doAccept(entity,context);
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var7) {
            code = -1;
            this.doException(this.request, busiDesc, model, var7);
        }
        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", Integer.valueOf(code));
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        ret.put("dict", model.remove("dict"));
        return ret.toJSONString();
    }


}