package com.mortals.xhx.module.goview.web;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.service.IUser;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.module.goview.model.*;
import com.mortals.xhx.module.goview.service.GoviewMasterplateDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.module.goview.service.GoviewMasterplateService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
*
* 模板表
*
* @author zxfei
* @date 2023-04-16
*/
@RestController
@RequestMapping("goview/masterplate")
public class GoviewMasterplateController extends BaseCRUDJsonBodyMappingController<GoviewMasterplateService,GoviewMasterplateEntity,Long> {

    @Autowired
    private ParamService paramService;
    @Autowired
    private GoviewMasterplateDataService goviewMasterplateDataService;

    public GoviewMasterplateController(){
        super.setModuleDesc( "模板表");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "state", paramService.getParamBySecondOrganize("GoviewMasterplate","state"));
        super.init(model, context);
    }

    @RequestMapping(value = {"getData"},method = {RequestMethod.GET})
    public Rest<Object> getData(Long masterplateId, ModelMap map) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询模板关联数据";
        int code;
        try {
            GoviewMasterplateEntity goviewProjectEntity = service.get(masterplateId);
            if(goviewProjectEntity==null){
                throw new AppException("模板ID不正确，无对应数据");
            }
            GoviewMasterplateDataEntity goviewProjectDataEntity = this.goviewMasterplateDataService.selectOne(new GoviewMasterplateDataQuery().masterplateId(masterplateId));
            if(goviewProjectEntity!=null && goviewProjectDataEntity!=null){
                byte[] bs= goviewProjectDataEntity.getContent();
                String str="二进制转换错误";
                str = new String(bs);
                goviewProjectEntity.setContent(str);
            }
            model.put("data", goviewProjectEntity);
            code = 1;
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        ret.setCode(code);
        ret.setData(model.get("data"));
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @PostMapping({"save/data"})
    public String saveData(GoviewMasterplateDataEntity entity) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "保存模板数据";
        int code=1;
        try {
            IUser user = this.getCurUser();
            if(entity.getMasterplateId()==null){
                throw new AppException("模板ID不能为空");
            }
            GoviewMasterplateDataEntity old = goviewMasterplateDataService.selectOne(new GoviewMasterplateDataQuery().masterplateId(entity.getMasterplateId()));
            if(old==null){
                entity.setCreateTime(new Date());
                entity.setUpdateTime(entity.getCreateTime());
                if (user != null) {
                    entity.setCreateUserId(user.getId());
                }
                this.goviewMasterplateDataService.save(entity, context);
            }else {
                entity.setId(old.getId());
                entity.setUpdateTime(new Date());
                this.goviewMasterplateDataService.update(entity, context);
            }

            model.put("id", entity.getId());
            model.put("entity", entity);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
        } catch (Exception var7) {
            this.doException(this.request, busiDesc, model, var7);
            model.put("entity", entity);
            code = -1;
        }
        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

    /**
     * 使用模板
     * @param entity
     * @return
     */
    @PostMapping({"use/masterplate"})
    public String useMasterplate(@RequestBody GoviewMasterplateEntity entity) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "使用模板";
        int code=1;
        try {
            if(entity.getId()==null){
                throw new AppException("模板ID不能为空");
            }
            service.useMasterplate(entity.getId(), context);
            model.put("id", entity.getId());
            model.put("entity", entity);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
        } catch (Exception var7) {
            this.doException(this.request, busiDesc, model, var7);
            model.put("entity", entity);
            code = -1;
        }
        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

}