package com.mortals.xhx.module.goview.web;
import com.mortals.framework.annotation.RepeatSubmit;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.service.IUser;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.framework.web.BaseJsonBodyController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.common.key.Constant;
import com.mortals.xhx.module.goview.model.GoviewProjectDataEntity;
import com.mortals.xhx.module.goview.model.GoviewProjectDataQuery;
import com.mortals.xhx.module.goview.service.GoviewProjectDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.ui.ModelMap;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.module.goview.model.GoviewProjectEntity;
import com.mortals.xhx.module.goview.service.GoviewProjectService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
 *
 * 项目
 *
 * @author zxfei
 * @date 2023-04-13
 */
@RestController
@RequestMapping("api/goview/project")
public class GoviewProjectAPi extends BaseJsonBodyController {

    @Autowired
    private ParamService paramService;
    @Autowired
    private GoviewProjectService goviewProjectService;
    @Autowired
    private GoviewProjectDataService goviewProjectDataService;


    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "state", paramService.getParamBySecondOrganize("GoviewProject","state"));
        //super.init(model, context);
    }

    protected PageInfo buildPageInfo(GoviewProjectEntity query) {
        PageInfo pageInfo = new PageInfo();
        if (!ObjectUtils.isEmpty(query) && !ObjectUtils.isEmpty(query.getPage())) {
            pageInfo.setCurrPage(query.getPage());
        }

        if (!ObjectUtils.isEmpty(query) && !ObjectUtils.isEmpty(query.getSize())) {
            pageInfo.setPrePageResult(query.getSize());
        }

        return pageInfo;
    }

    protected void parsePageInfo(Map<String, Object> model, PageInfo pageInfo) {
        model.put("total", pageInfo.getTotalResult());
        model.put("per_page", pageInfo.getPrePageResult());
        model.put("current_page", pageInfo.getCurrPage());
        model.put("last_page", pageInfo.getTotalPage());
        model.put("pageInfo", pageInfo);
    }

    @RequestMapping(value = {"list"},method = {RequestMethod.GET})
    public Rest<Object> list(Integer page,Integer limit) {
        GoviewProjectEntity query = new GoviewProjectEntity();
        query.setPage(page);
        query.setSize(limit);
        IUser user = this.getCurUser();
        if (user != null && user.getUserType() == Constant.CUSTOMER_USER) {
            query.setCustomerId(user.getId());
        }
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询项目";

        int code;
        try {
            PageInfo pageInfo = this.buildPageInfo(query);
//            this.doListBefore(query, model, context);
            Result<GoviewProjectEntity> result = goviewProjectService.find(query, pageInfo, context);
            model.put("data", result.getList());
            model.put("pageInfo", result.getPageInfo());
            this.parsePageInfo(model, result.getPageInfo());
            code = 1;
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        this.init(model, context);
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @PostMapping({"create"})
    @RepeatSubmit
    public String create(@RequestBody GoviewProjectEntity entity) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "新增项目信息";
        int code=1;
        try {
            IUser user;
            entity.setCreateTime(new Date());
            entity.setUpdateTime(entity.getCreateTime());
            user = this.getCurUser();
            if (user != null && user.getUserType() == Constant.CUSTOMER_USER) {
                entity.setCreateUserId(user.getId());
                entity.setCustomerId(user.getId());
            }
            goviewProjectService.save(entity, context);
            model.put("id", entity.getId());
            model.put("entity", entity);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
        } catch (Exception var7) {
            this.doException(this.request, busiDesc, model, var7);
            model.put("entity", entity);
            code = -1;
        }
        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

    @PostMapping({"edit"})
    public String editNew(@RequestBody GoviewProjectEntity entity) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "修改项目信息";
        int code=1;
        try {
            if(entity.getId()==null){
                throw new AppException("项目ID不能为空");
            }
            IUser user;
            entity.setUpdateTime(new Date());
            user = this.getCurUser();
            if (user != null) {
                entity.setUpdateUserId(user.getId());
            }
            goviewProjectService.update(entity, context);
            model.put("id", entity.getId());
            model.put("entity", entity);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
        } catch (Exception var7) {
            this.doException(this.request, busiDesc, model, var7);
            model.put("entity", entity);
            code = -1;
        }
        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

    @PostMapping({"rename"})
    public String rename(@RequestBody GoviewProjectEntity entity) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "修改项目信息";
        int code=1;
        try {
            if(entity.getId()==null){
                throw new AppException("项目ID不能为空");
            }
            if(StringUtils.isEmpty(entity.getProjectName())){
                throw new AppException("项目名称不能为空");
            }
            GoviewProjectEntity update = new GoviewProjectEntity();
            update.setId(entity.getId());
            update.setProjectName(entity.getProjectName());
            IUser user;
            entity.setUpdateTime(new Date());
            user = this.getCurUser();
            if (user != null) {
                update.setUpdateUserId(user.getId());
            }
            goviewProjectService.update(update, context);
            model.put("id", entity.getId());
            model.put("entity", entity);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
        } catch (Exception var7) {
            this.doException(this.request, busiDesc, model, var7);
            model.put("entity", entity);
            code = -1;
        }
        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

    /**
     * 发布/取消项目状态
     * @param entity
     * @return
     */
    @PostMapping({"publish"})
    public String publish(@RequestBody GoviewProjectEntity entity) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "发布/取消项目状态";
        int code=1;
        try {
            if(entity.getId()==null){
                throw new AppException("项目ID不能为空");
            }
            if(entity.getState()==null){
                throw new AppException("项目状态不能为空");
            }
            if(entity.getState()==-1||entity.getState()==1) {
                GoviewProjectEntity update = new GoviewProjectEntity();
                update.setId(entity.getId());
                update.setState(entity.getState());
                IUser user;
                entity.setUpdateTime(new Date());
                user = this.getCurUser();
                if (user != null) {
                    update.setUpdateUserId(user.getId());
                }
                goviewProjectService.update(update, context);
                model.put("id", entity.getId());
                model.put("entity", entity);
                model.put("message_info", busiDesc + "成功");
                this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
            }else {
                throw new AppException("项目状态值非法，只能为-1或1");
            }
        } catch (Exception var7) {
            this.doException(this.request, busiDesc, model, var7);
            model.put("entity", entity);
            code = -1;
        }
        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

    @RequestMapping(value = {"getData"},method = {RequestMethod.GET})
    public Rest<Object> getData(Long projectId, ModelMap map) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询项目关联数据";
        int code;
        try {
            GoviewProjectEntity goviewProjectEntity = goviewProjectService.get(projectId);
            GoviewProjectDataEntity goviewProjectDataEntity = this.goviewProjectDataService.selectOne(new GoviewProjectDataQuery().projectId(projectId));
            if(goviewProjectEntity!=null && goviewProjectDataEntity!=null){
                byte[] bs= goviewProjectDataEntity.getContent();
                String str="二进制转换错误";
                str = new String(bs);
                goviewProjectEntity.setContent(str);
            }
            model.put("data", goviewProjectEntity);
            code = 1;
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        ret.setCode(code);
        ret.setData(model.get("data"));
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @PostMapping({"save/data"})
    public String saveData(GoviewProjectDataEntity entity) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "保存项目数据";
        int code=1;
        try {
            IUser user = this.getCurUser();
            if(entity.getProjectId()==null){
                throw new AppException("项目ID不能为空");
            }
            GoviewProjectDataEntity old = goviewProjectDataService.selectOne(new GoviewProjectDataQuery().projectId(entity.getProjectId()));
            if(old==null){
                entity.setCreateTime(new Date());
                entity.setUpdateTime(entity.getCreateTime());
                if (user != null) {
                    entity.setCreateUserId(user.getId());
                }
                this.goviewProjectDataService.save(entity, context);
            }else {
                entity.setId(old.getId());
                entity.setUpdateTime(new Date());
                this.goviewProjectDataService.update(entity, context);
            }

            model.put("id", entity.getId());
            model.put("entity", entity);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
        } catch (Exception var7) {
            this.doException(this.request, busiDesc, model, var7);
            model.put("entity", entity);
            code = -1;
        }
        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

    /**
     * 发布为模板
     * @param entity
     * @return
     */
    @PostMapping({"publish/masterplate"})
    public String publishMasterplate(@RequestBody GoviewProjectEntity entity) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "发布模板";
        int code=1;
        try {
            if(entity.getId()==null){
                throw new AppException("项目ID不能为空");
            }
            goviewProjectService.publishMasterplate(entity.getId(), context);
            model.put("id", entity.getId());
            model.put("entity", entity);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
        } catch (Exception var7) {
            this.doException(this.request, busiDesc, model, var7);
            model.put("entity", entity);
            code = -1;
        }
        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

    @RequestMapping(
            value = {"delete"},
            method = {RequestMethod.POST, RequestMethod.GET}
    )
    public String delete(Long[] id) {
        Context context = this.getContext();
        if (id == null) {
            return this.createFailJsonResp("请至少选择一条记录");
        } else {
            Map<String, Object> model = new HashMap();
            int code = 1;
            String busiDesc = "删除項目";

            try {

                int iRet = this.goviewProjectService.remove(id, context);
                model.put("message_info", "項目信息删除成功!删除条数:" + iRet);
                this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + StringUtils.converArray2Str(id) + "]");
            } catch (Exception var7) {
                code = -1;
                this.doException(this.request, busiDesc, model, var7);
            }

            JSONObject ret = new JSONObject();
            ret.put("code", Integer.valueOf(code));
            ret.put("msg", model.remove("message_info"));
            ret.put("data", model);
            return ret.toJSONString();
        }
    }
}