package com.mortals.xhx.module.message.service.impl;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.common.code.MemberLevelEnum;
import com.mortals.xhx.common.code.ReadStatusEnum;
import com.mortals.xhx.common.code.SendScopeEnum;
import com.mortals.xhx.common.utils.StringUtils;
import com.mortals.xhx.module.customer.model.CustomerEntity;
import com.mortals.xhx.module.customer.model.CustomerQuery;
import com.mortals.xhx.module.customer.service.CustomerService;
import com.mortals.xhx.module.message.dao.MessageDao;
import com.mortals.xhx.module.message.model.MessageEntity;
import com.mortals.xhx.module.message.service.MessageService;
import com.mortals.xhx.module.news.model.NewsEntity;
import com.mortals.xhx.module.news.model.NewsQuery;
import com.mortals.xhx.module.news.service.NewsService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.Duration;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
* MessageService
* 客户建议信息 service实现
*
* @author zxfei
* @date 2022-06-28
*/
@Service("messageService")
public class MessageServiceImpl extends AbstractCRUDServiceImpl<MessageDao, MessageEntity, Long> implements MessageService {

    @Autowired
    private NewsService newsService;
    @Autowired
    private CustomerService customerService;

    @Override
    protected MessageEntity findBefore(MessageEntity entity, PageInfo pageInfo, Context context) throws AppException {
        if(StringUtils.isNotEmpty(entity.getContent())){
            StringBuffer condition = new StringBuffer("%");
            condition.append(entity.getContent()).append("%");
            entity.setContent(condition.toString());
        }
        return entity;
    }

    @Override
    protected void saveAfter(MessageEntity entity, Context context) throws AppException {
        CustomerQuery customerQuery = new CustomerQuery();
        List<Integer> memberLevel = new ArrayList<>();
        if(entity.getScope()== SendScopeEnum.VIP.getValue()){
            memberLevel.add(MemberLevelEnum.VIP.getValue());
        }
        if(entity.getScope()== SendScopeEnum.ORDINARY.getValue()){
            memberLevel.add(MemberLevelEnum.NOT_OPEN.getValue());
        }else {
            memberLevel.add(MemberLevelEnum.VIP.getValue());
            memberLevel.add(MemberLevelEnum.NOT_OPEN.getValue());
        }
        List<CustomerEntity> customerEntities = customerService.find(customerQuery,context);
        if(CollectionUtils.isNotEmpty(customerEntities)){
            List<NewsEntity> newsEntities = new ArrayList<>();
            Date now = new Date();
            customerEntities.stream().forEach(item->{
                NewsEntity newsEntity = new NewsEntity();
                newsEntity.setMessageId(entity.getId());
                newsEntity.setCustomerId(item.getId());
                newsEntity.setTitle(entity.getTitle());
                newsEntity.setContent(entity.getContent());
                newsEntity.setMessageType(entity.getMessageType());
                newsEntity.setReadStatus(ReadStatusEnum.UN_READ.getValue());
                newsEntity.setReceiveTime(now);
                newsEntities.add(newsEntity);
            });
            newsService.save(newsEntities,context);
        }
    }

    @Override
    protected void removeBefore(Long[] ids, Context context) throws AppException {
        List<MessageEntity> entities = this.get(ids,context);
        Date now = new Date();
        for(MessageEntity messageEntity:entities){
            long between = now.getTime()-messageEntity.getCreateTime().getTime();
            if(between>600000){
                throw new AppException("超过十分钟，不能撤回");
            }
        }
    }

    @Override
    protected void removeAfter(Long[] ids, Context context, int result) throws AppException {
        NewsQuery condition = new NewsQuery();
        List<Long> messageIds = Arrays.asList(ids);
        condition.setMessageIdList(messageIds);
        newsService.remove(condition,context);
    }
}