package com.mortals.xhx.module.picture.service.impl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.util.DateUtils;
import com.mortals.framework.util.StringUtils;
import com.mortals.xhx.base.system.param.model.ParamEntity;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.module.picture.model.vo.PictureGroupCountVo;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.module.picture.dao.PictureMaterialDao;
import com.mortals.xhx.module.picture.model.PictureMaterialEntity;
import com.mortals.xhx.module.picture.service.PictureMaterialService;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
* PictureMaterialService
* 图片素材 service实现
*
* @author zxfei
* @date 2022-06-08
*/
@Service("pictureMaterialService")
public class PictureMaterialServiceImpl extends AbstractCRUDServiceImpl<PictureMaterialDao, PictureMaterialEntity, Long> implements PictureMaterialService {

    @Autowired
    private ParamService paramService;

    @Override
    protected PictureMaterialEntity findBefore(PictureMaterialEntity entity, PageInfo pageInfo, Context context) throws AppException {
        if(StringUtils.isNotEmpty(entity.getPictureName())){
            entity.setPictureName("%".concat(entity.getPictureName()).concat("%"));
        }
        return entity;
    }

    @Override
    protected void findAfter(PictureMaterialEntity entity, PageInfo pageInfo, Context context, List<PictureMaterialEntity> list) throws AppException {
        if(CollectionUtils.isNotEmpty(list)){
            Map<String,String> map = paramService.getParamBySecondOrganize("PictureMaterial","pictureGroupId");
            list.stream().forEach(item->{
                item.setCreateTimeStr(DateUtils.getDateTime(item.getCreateTime(),DateUtils.P_yyyy_MM_dd_HH_mm_ss));
                if(map.containsKey(item.getPictureGroupId().toString())) {
                    item.setPictureGroupName(map.get(item.getPictureGroupId().toString()));
                }else {
                    item.setPictureGroupName(item.getPictureGroupId().toString());
                }
            });
        }
    }

    @Override
    public List<PictureGroupCountVo> selectPictureGroupCount(int pictureType) {
        return dao.selectPictureGroupCount(pictureType);
    }

    @Override
    protected void validData(PictureMaterialEntity entity, Context context) throws AppException {
        if(StringUtils.isEmpty(entity.getPicturePath())){
            throw new AppException("文件地址不能为空");
        }
        if(StringUtils.isEmpty(entity.getPictureName())){
            throw new AppException("文件名称不能为空");
        }
        if(entity.getPictureGroupId()==null){
            throw new AppException("素材分组不能为空");
        }
        if(entity.getPictureClassifyId()==null){
            throw new AppException("素材分类不能为空");
        }
        if(StringUtils.isEmpty(entity.getFileName())){
            throw new AppException("文件名称不能为空");
        }
    }

}