package com.mortals.xhx.module.question.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.RepeatSubmit;
import com.mortals.framework.common.IBaseEnum;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.service.IUser;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.common.code.EvaluateLevelEnum;
import com.mortals.xhx.common.code.QuestionStatusEnum;
import com.mortals.xhx.common.key.Constant;
import com.mortals.xhx.module.customer.model.CustomerEntity;
import com.mortals.xhx.module.question.model.QuestionEntity;
import com.mortals.xhx.module.question.service.QuestionService;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;
/**
*
* 问答信息
*
* @author zxfei
* @date 2022-06-28
*/
@RestController
@RequestMapping("question")
public class QuestionController extends BaseCRUDJsonBodyMappingController<QuestionService,QuestionEntity,Long> {

    public QuestionController(){
        super.setModuleDesc( "问答信息");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "status", IBaseEnum.getEnumMap(QuestionStatusEnum.class));
        this.addDict(model, "evaluate", IBaseEnum.getEnumMap(EvaluateLevelEnum.class));
        super.init(model, context);
    }

    @Override
    protected void doListBefore(QuestionEntity query, Map<String, Object> model, Context context) throws AppException {
        Map<String,String> orderCols = new HashMap<>();
        orderCols.put("beginTime","DESC");
        query.setOrderCols(orderCols);
    }

    @PostMapping({"evaluate"})
    public String evaluate(@RequestBody QuestionEntity entity){
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "新增咨询" + this.getModuleDesc();
        int code = 1;
        try {
            if(this.getCurUser()==null||this.getCurUser().getUserType()!= Constant.CUSTOMER_USER){
                throw new AppException("非法用户,不可访问");
            }

            entity = this.service.update(entity,context);
            model.put("entity", entity);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
        } catch (Exception var7) {
            this.doException(this.request, busiDesc, model, var7);
            model.put("entity", entity);
            this.init(model, context);
            code = this.saveException(entity, model, context, var7);
        }

        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }
}